# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0004_auto_20171009_2008'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='contact',
            options={'verbose_name': 'Contact', 'verbose_name_plural': 'Contact'},
        ),
        migrations.AlterModelOptions(
            name='contract',
            options={'verbose_name': 'Contract', 'verbose_name_plural': 'Contracts'},
        ),
        migrations.AlterModelOptions(
            name='currency',
            options={'verbose_name': 'Currency', 'verbose_name_plural': 'Currency'},
        ),
        migrations.AlterModelOptions(
            name='customer',
            options={'verbose_name': 'Customer', 'verbose_name_plural': 'Customers'},
        ),
        migrations.AlterModelOptions(
            name='customerbillingcycle',
            options={'verbose_name': 'Customer Billing Cycle', 'verbose_name_plural': 'Customer Billing Cycle'},
        ),
        migrations.AlterModelOptions(
            name='customergroup',
            options={'verbose_name': 'Customer Group', 'verbose_name_plural': 'Customer Groups'},
        ),
        migrations.AlterModelOptions(
            name='customergrouptransform',
            options={'verbose_name': 'Customer Group Price Transfrom', 'verbose_name_plural': 'Customer Group Price Transfroms'},
        ),
        migrations.AlterModelOptions(
            name='emailaddress',
            options={'verbose_name': 'Email Address', 'verbose_name_plural': 'Email Address'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontact',
            options={'verbose_name': 'Email Address For Contact', 'verbose_name_plural': 'Email Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforcontract',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforpurchaseorder',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='emailaddressforsalescontract',
            options={'verbose_name': 'Email Address For Contracts', 'verbose_name_plural': 'Email Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='invoice',
            options={'verbose_name': 'Invoice', 'verbose_name_plural': 'Invoices'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddress',
            options={'verbose_name': 'Phone Address', 'verbose_name_plural': 'Phone Address'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontact',
            options={'verbose_name': 'Phone Address For Contact', 'verbose_name_plural': 'Phone Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforcontract',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforpurchaseorder',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='phoneaddressforsalescontract',
            options={'verbose_name': 'Phone Address For Contracts', 'verbose_name_plural': 'Phone Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='position',
            options={'verbose_name': 'Position', 'verbose_name_plural': 'Positions'},
        ),
        migrations.AlterModelOptions(
            name='postaladdress',
            options={'verbose_name': 'Postal Address', 'verbose_name_plural': 'Postal Address'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontact',
            options={'verbose_name': 'Postal Address For Contact', 'verbose_name_plural': 'Postal Address For Contact'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforcontract',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforpurchaseorder',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='postaladdressforsalescontract',
            options={'verbose_name': 'Postal Address For Contracts', 'verbose_name_plural': 'Postal Address For Contracts'},
        ),
        migrations.AlterModelOptions(
            name='price',
            options={'verbose_name': 'Price', 'verbose_name_plural': 'Prices'},
        ),
        migrations.AlterModelOptions(
            name='product',
            options={'verbose_name': 'Product', 'verbose_name_plural': 'Products'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorder',
            options={'verbose_name': 'Purchase Order', 'verbose_name_plural': 'Purchase Order'},
        ),
        migrations.AlterModelOptions(
            name='purchaseorderposition',
            options={'verbose_name': 'Purchaseorder Position', 'verbose_name_plural': 'Purchaseorder Positions'},
        ),
        migrations.AlterModelOptions(
            name='quote',
            options={'verbose_name': 'Quote', 'verbose_name_plural': 'Quotes'},
        ),
        migrations.AlterModelOptions(
            name='salescontract',
            options={'verbose_name': 'Sales Contract', 'verbose_name_plural': 'Sales Contracts'},
        ),
        migrations.AlterModelOptions(
            name='salescontractposition',
            options={'verbose_name': 'Salescontract Position', 'verbose_name_plural': 'Salescontract Positions'},
        ),
        migrations.AlterModelOptions(
            name='supplier',
            options={'verbose_name': 'Supplier', 'verbose_name_plural': 'Supplier'},
        ),
        migrations.AlterModelOptions(
            name='tax',
            options={'verbose_name': 'Tax', 'verbose_name_plural': 'Taxes'},
        ),
        migrations.AlterModelOptions(
            name='unit',
            options={'verbose_name': 'Unit', 'verbose_name_plural': 'Units'},
        ),
        migrations.AlterModelOptions(
            name='unittransform',
            options={'verbose_name': 'Unit Transfrom', 'verbose_name_plural': 'Unit Transfroms'},
        ),
        migrations.AlterField(
            model_name='contact',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='contact',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultSupplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Default Supplier'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcurrency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Default Currency'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='defaultcustomer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Default Customer'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='description',
            field=models.TextField(verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_contractlstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='contract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relcontractstaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='rounding',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rounding'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Displayed Name After Price In The Position'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='defaultCustomerBillingCycle',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerBillingCycle', verbose_name='Default Billing Cycle'),
        ),
        migrations.AlterField(
            model_name='customer',
            name='ismemberof',
            field=models.ManyToManyField(blank=True, to='crm.CustomerGroup', verbose_name='Is member of'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='name',
            field=models.CharField(max_length=300, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='customerbillingcycle',
            name='timeToPaymentDate',
            field=models.IntegerField(verbose_name='Days To Payment Date'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Customer Group'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='fromCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromcustomergroup', to='crm.CustomerGroup', verbose_name='From Unit'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='customergrouptransform',
            name='toCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtocustomergroup', to='crm.CustomerGroup', verbose_name='To Unit'),
        ),
        migrations.AlterField(
            model_name='emailaddress',
            name='email',
            field=models.EmailField(max_length=200, verbose_name='Email Address'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='emailaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='payableuntil',
            field=models.DateField(verbose_name='To pay until'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='paymentBankReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Payment Bank Reference'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='status',
            field=models.CharField(choices=[('P', 'Payed'), ('C', 'Invoice created'), ('I', 'Invoice sent'), ('F', 'First reminder sent'), ('R', 'Second reminder sent'), ('U', 'Customer cant pay'), ('D', 'Deleted')], max_length=1),
        ),
        migrations.AlterField(
            model_name='phoneaddress',
            name='phone',
            field=models.CharField(max_length=20, verbose_name='Phone Number'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='phoneaddressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='position',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='position',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Price'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Tax'),
        ),
        migrations.AlterField(
            model_name='position',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Last Pricing Date'),
        ),
        migrations.AlterField(
            model_name='position',
            name='overwriteProductPrice',
            field=models.BooleanField(verbose_name='Overwrite Product Price'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionNumber',
            field=models.IntegerField(verbose_name='Position Number'),
        ),
        migrations.AlterField(
            model_name='position',
            name='positionPricePerUnit',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Price Per Unit'),
        ),
        migrations.AlterField(
            model_name='position',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='position',
            name='quantity',
            field=models.DecimalField(decimal_places=3, max_digits=10, verbose_name='Quantity'),
        ),
        migrations.AlterField(
            model_name='position',
            name='sentOn',
            field=models.DateField(blank=True, null=True, verbose_name='Shipment on'),
        ),
        migrations.AlterField(
            model_name='position',
            name='shipmentID',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Shipment ID'),
        ),
        migrations.AlterField(
            model_name='position',
            name='supplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Shipment Supplier'),
        ),
        migrations.AlterField(
            model_name='position',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline1',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 1'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline2',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 2'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline3',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 3'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='addressline4',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 4'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='country',
            field=models.CharField(blank=True, choices=[('AF', 'Afghanistan'), ('AX', 'Aland Islands'), ('AL', 'Albania'), ('DZ', 'Algeria'), ('AS', 'American Samoa'), ('AD', 'Andorra'), ('AO', 'Angola'), ('AI', 'Anguilla'), ('AQ', 'Antarctica'), ('AG', 'Antigua and Barbuda'), ('AR', 'Argentina'), ('AM', 'Armenia'), ('AW', 'Aruba'), ('AU', 'Australia'), ('AT', 'Austria'), ('AZ', 'Azerbaijan'), ('BS', 'the Bahamas'), ('BH', 'Bahrain'), ('BD', 'Bangladesh'), ('BB', 'Barbados'), ('BY', 'Belarus'), ('BE', 'Belgium'), ('BZ', 'Belize'), ('BJ', 'Benin'), ('BM', 'Bermuda'), ('BT', 'Bhutan'), ('BO', 'Bolivia'), ('BA', 'Bosnia and Herzegovina'), ('BW', 'Botswana'), ('BV', 'Bouvet Island'), ('BR', 'Brazil'), ('IO', 'British Indian Ocean Territory'), ('BN', 'Brunei Darussalam'), ('BG', 'Bulgaria'), ('BF', 'Burkina Faso'), ('BI', 'Burundi'), ('KH', 'Cambodia'), ('CM', 'Cameroon'), ('CA', 'Canada'), ('CV', 'Cape Verde'), ('KY', 'Cayman Islands'), ('CF', 'Central African Republic'), ('TD', 'Chad'), ('CL', 'Chile'), ('CN', 'China'), ('CX', 'Christmas Island'), ('CC', 'Cocos (Keeling) Islands'), ('CO', 'Colombia'), ('KM', 'Comoros'), ('CG', 'Congo'), ('CD', 'Democratic Republic of the Congo'), ('CK', 'Cook Islands'), ('CR', 'Costa Rica'), ('CI', "Cote d'Ivoire"), ('HR', 'Croatia'), ('CU', 'Cuba'), ('CY', 'Cyprus'), ('CZ', 'Czech Republic'), ('DK', 'Denmark'), ('DJ', 'Djibouti'), ('DM', 'Dominica'), ('DO', 'Dominican Republic'), ('EC', 'Ecuador'), ('EG', 'Egypt'), ('SV', 'El Salvador'), ('GQ', 'Equatorial Guinea'), ('ER', 'Eritrea'), ('EE', 'Estonia'), ('ET', 'Ethiopia'), ('FK', 'Falkland Islands (Malvinas)'), ('FO', 'Faroe Islands'), ('FJ', 'Fiji'), ('FI', 'Finland'), ('FR', 'France'), ('GF', 'French Guiana'), ('PF', 'French Polynesia'), ('TF', 'French Southern and Antarctic Lands'), ('GA', 'Gabon'), ('GM', 'Gambia'), ('GE', 'Georgia'), ('DE', 'Germany'), ('GH', 'Ghana'), ('GI', 'Gibraltar'), ('GR', 'Greece'), ('GL', 'Greenland'), ('GD', 'Grenada'), ('GP', 'Guadeloupe'), ('GU', 'Guam'), ('GT', 'Guatemala'), ('GG', 'Guernsey'), ('GN', 'Guinea'), ('GW', 'Guinea-Bissau'), ('GY', 'Guyana'), ('HT', 'Haiti'), ('HM', 'Heard Island and McDonald Islands'), ('VA', 'Vatican City Holy See'), ('HN', 'Honduras'), ('HK', 'Hong Kong'), ('HU', 'Hungary'), ('IS', 'Iceland'), ('IN', 'India'), ('ID', 'Indonesia'), ('IR', 'Iran'), ('IQ', 'Iraq'), ('IE', 'Ireland'), ('IM', 'Isle of Man'), ('IL', 'Israel'), ('IT', 'Italy'), ('JM', 'Jamaica'), ('JP', 'Japan'), ('JE', 'Jersey'), ('JO', 'Jordan'), ('KZ', 'Kazakhstan'), ('KE', 'Kenya'), ('KI', 'Kiribati'), ('KP', 'North Korea'), ('KR', 'South Korea'), ('KW', 'Kuwait'), ('KG', 'Kyrgyzstan'), ('LA', 'Laos Lao'), ('LV', 'Latvia'), ('LB', 'Lebanon'), ('LS', 'Lesotho'), ('LR', 'Liberia'), ('LY', 'Libya Libyan Arab Jamahiriya'), ('LI', 'Liechtenstein'), ('LT', 'Lithuania'), ('LU', 'Luxembourg'), ('MO', 'Macau Macao'), ('MK', 'Macedonia'), ('MG', 'Madagascar'), ('MW', 'Malawi'), ('MY', 'Malaysia'), ('MV', 'Maldives'), ('ML', 'Mali'), ('MT', 'Malta'), ('MH', 'Marshall Islands'), ('MQ', 'Martinique'), ('MR', 'Mauritania'), ('MU', 'Mauritius'), ('YT', 'Mayotte'), ('MX', 'Mexico'), ('FM', 'Micronesia'), ('MD', 'Moldova'), ('MC', 'Monaco'), ('MN', 'Mongolia'), ('ME', 'Montenegro'), ('MS', 'Montserrat'), ('MA', 'Morocco'), ('MZ', 'Mozambique'), ('MM', 'Myanmar'), ('NA', 'Namibia'), ('NR', 'Nauru'), ('NP', 'Nepal'), ('NL', 'Netherlands'), ('AN', 'Netherlands Antilles'), ('NC', 'New Caledonia'), ('NZ', 'New Zealand'), ('NI', 'Nicaragua'), ('NE', 'Niger'), ('NG', 'Nigeria'), ('NU', 'Niue'), ('NF', 'Norfolk Island Norfolk Island'), ('MP', 'Northern Mariana Islands'), ('NO', 'Norway'), ('OM', 'Oman'), ('PK', 'Pakistan'), ('PW', 'Palau'), ('PS', 'Palestinian Territory'), ('PA', 'Panama'), ('PG', 'Papua New Guinea'), ('PY', 'Paraguay'), ('PE', 'Peru'), ('PH', 'Philippines'), ('PN', 'Pitcairn Islands'), ('PL', 'Poland'), ('PT', 'Portugal'), ('PR', 'Puerto Rico'), ('QA', 'Qatar'), ('RE', 'Reunion'), ('RO', 'Romania'), ('RU', 'Russia'), ('RW', 'Rwanda'), ('SH', 'Saint Helena'), ('KN', 'Saint Kitts and Nevis'), ('LC', 'Saint Lucia'), ('PM', 'Saint Pierre and Miquelon'), ('VC', 'Saint Vincent and the Grenadines'), ('WS', 'Samoa'), ('SM', 'San Marino'), ('ST', 'Sao Tome and Principe'), ('SA', 'Saudi Arabia'), ('SN', 'Senegal'), ('RS', 'Serbia'), ('SC', 'Seychelles'), ('SL', 'Sierra Leone'), ('SG', 'Singapore'), ('SK', 'Slovakia'), ('SI', 'Slovenia'), ('SB', 'Solomon Islands'), ('SO', 'Somalia'), ('ZA', 'South Africa'), ('GS', 'South Georgia and the South Sandwich Islands'), ('ES', 'Spain'), ('LK', 'Sri Lanka'), ('SD', 'Sudan'), ('SR', 'Suriname'), ('SJ', 'Svalbard and Jan Mayen'), ('SZ', 'Swaziland'), ('SE', 'Sweden'), ('CH', 'Switzerland'), ('SY', 'Syria'), ('TW', 'Taiwan'), ('TJ', 'Tajikistan'), ('TZ', 'Tanzania'), ('TH', 'Thailand'), ('TL', 'East Timor'), ('TG', 'Togo'), ('TK', 'Tokelau'), ('TO', 'Tonga'), ('TT', 'Trinidad and Tobago'), ('TN', 'Tunisia'), ('TR', 'Turkey'), ('TM', 'Turkmenistan'), ('TC', 'Turks and Caicos Islands'), ('TV', 'Tuvalu'), ('UG', 'Uganda'), ('UA', 'Ukraine'), ('AE', 'United Arab Emirates'), ('GB', 'United Kingdom'), ('US', 'United States'), ('UM', 'United States Minor Outlying Islands'), ('UY', 'Uruguay'), ('UZ', 'Uzbekistan'), ('VU', 'Vanuatu'), ('VE', 'Venezuela'), ('VN', 'Vietnam Viet Nam'), ('VG', 'British Virgin Islands'), ('VI', 'United States Virgin Islands'), ('WF', 'Wallis and Futuna'), ('EH', 'Western Sahara'), ('YE', 'Yemen'), ('ZM', 'Zambia'), ('ZW', 'Zimbabwe')], max_length=2, null=True, verbose_name='Country'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='name',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prefix',
            field=models.CharField(blank=True, choices=[('F', 'Company'), ('W', 'Mrs'), ('H', 'Mr'), ('G', 'Ms')], max_length=1, null=True, verbose_name='Prefix'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='prename',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Prename'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='state',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='State'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='town',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='City'),
        ),
        migrations.AlterField(
            model_name='postaladdress',
            name='zipcode',
            field=models.IntegerField(blank=True, null=True, verbose_name='Zipcode'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontact',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforcontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforpurchaseorder',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='postaladdressforsalescontract',
            name='purpose',
            field=models.CharField(choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='price',
            name='customerGroup',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerGroup', verbose_name='Customer Group'),
        ),
        migrations.AlterField(
            model_name='price',
            name='price',
            field=models.DecimalField(decimal_places=2, max_digits=17, verbose_name='Price Per Unit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='price',
            name='unit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validfrom',
            field=models.DateField(blank=True, null=True, verbose_name='Valid from'),
        ),
        migrations.AlterField(
            model_name='price',
            name='validuntil',
            field=models.DateField(blank=True, null=True, verbose_name='Valid until'),
        ),
        migrations.AlterField(
            model_name='product',
            name='accoutingProductCategorie',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to='accounting.ProductCategorie', verbose_name='Accounting Product Categorie'),
        ),
        migrations.AlterField(
            model_name='product',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='product',
            name='defaultunit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AlterField(
            model_name='product',
            name='description',
            field=models.TextField(blank=True, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='product',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='product',
            name='productNumber',
            field=models.IntegerField(verbose_name='Product Number'),
        ),
        migrations.AlterField(
            model_name='product',
            name='title',
            field=models.CharField(max_length=200, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Currency'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='External Reference'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Price With Tax'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Last Calculted Tax'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Last Pricing Date'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_polstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relpostaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='status',
            field=models.CharField(choices=[('O', 'Ordered'), ('D', 'Delayed'), ('Y', 'Delivered'), ('I', 'Invoice registered'), ('P', 'Invoice payed')], max_length=1),
        ),
        migrations.AlterField(
            model_name='purchaseorder',
            name='supplier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier', verbose_name='Supplier'),
        ),
        migrations.AlterField(
            model_name='purchaseorderposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='status',
            field=models.CharField(choices=[('S', 'Success'), ('I', 'Quote created'), ('Q', 'Quote sent'), ('F', 'First reminder sent'), ('R', 'Second reminder sent'), ('D', 'Deleted')], max_length=1, verbose_name='Status'),
        ),
        migrations.AlterField(
            model_name='quote',
            name='validuntil',
            field=models.DateField(verbose_name='Valid until'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency', verbose_name='Currency'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Customer', verbose_name='Customer'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='dateofcreation',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Created at'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='description',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='discount',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='externalReference',
            field=models.CharField(blank=True, max_length=100, verbose_name='External Reference'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedPrice',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Price without Tax '),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastCalculatedTax',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True, verbose_name='Tax'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastPricingDate',
            field=models.DateField(blank=True, null=True, verbose_name='Pricing Date'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='last_print_date',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Last printed'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodification',
            field=models.DateTimeField(auto_now=True, verbose_name='Last modified'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_lstscmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='salescontract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relscstaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AlterField(
            model_name='salescontractposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract', verbose_name='Contract'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountActiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountactiva', to='accounting.Account', verbose_name='Activa Account'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='accountPassiva',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_relaccountpassiva', to='accounting.Account', verbose_name='Passiva Account'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='name',
            field=models.CharField(max_length=100, verbose_name='Taxname'),
        ),
        migrations.AlterField(
            model_name='tax',
            name='taxrate',
            field=models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Taxrate in Percentage'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='description',
            field=models.CharField(max_length=100, verbose_name='Description'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='fractionFactorToNextHigherUnit',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor Between This And Next Higher Unit'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='isAFractionOf',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Is A Fraction Of'),
        ),
        migrations.AlterField(
            model_name='unit',
            name='shortName',
            field=models.CharField(max_length=3, verbose_name='Displayed Name After Quantity In The Position'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='factor',
            field=models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Unit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='fromUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromunit', to='crm.Unit', verbose_name='From Unit'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product', verbose_name='Product'),
        ),
        migrations.AlterField(
            model_name='unittransform',
            name='toUnit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtounit', to='crm.Unit', verbose_name='To Unit'),
        ),
    ]



# Generated by Django 2.1.4 on 2018-12-16 22:24

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('accounting', '0009_auto_20181012_2056'),
    ]

    operations = [
        migrations.AlterField(
            model_name='booking',
            name='last_modified_by',
            field=models.ForeignKey(blank=True, limit_choices_to={'is_staff': True}, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_lstmodified', to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AlterField(
            model_name='booking',
            name='staff',
            field=models.ForeignKey(blank=True, limit_choices_to={'is_staff': True}, on_delete=django.db.models.deletion.CASCADE, related_name='db_booking_refstaff', to=settings.AUTH_USER_MODEL, verbose_name='Reference Staff'),
        ),
        migrations.AlterField(
            model_name='productcategory',
            name='loss_account',
            field=models.ForeignKey(limit_choices_to={'account_type': 'S'}, on_delete=django.db.models.deletion.CASCADE, related_name='db_loss_account', to='accounting.Account', verbose_name='Loss Account'),
        ),
        migrations.AlterField(
            model_name='productcategory',
            name='profit_account',
            field=models.ForeignKey(limit_choices_to={'account_type': 'E'}, on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_account', to='accounting.Account', verbose_name='Profit Account'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-11 20:31
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):
    atomic = False

    dependencies = [
        ('crm', '0017_auto_20180111_2022'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='textparagraphinsalesdocument',
            options={'verbose_name': 'Text Paragraph In Sales Document', 'verbose_name_plural': 'Text Paragraphs In Sales Documents'},
        ),
        migrations.RenameField(
            model_name='deliverynote',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='emailaddressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='invoice',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='paymentreminder',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='phoneaddressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='postaladdressforsalesdocument',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='purchaseconfirmation',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='quote',
            old_name='salescontract_ptr',
            new_name='salesdocument_ptr',
        ),
        migrations.RenameField(
            model_name='salesdocumentposition',
            old_name='contract',
            new_name='sales_document',
        ),
        migrations.RenameField(
            model_name='textparagraphinsalesdocument',
            old_name='sales_contract',
            new_name='sales_document',
        ),
    ]



# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext as _
from koalixcrm.crm.const.postaladdressprefix import *


class Person(models.Model):
    prefix = models.CharField(max_length=1,
                              choices=POSTALADDRESSPREFIX,
                              verbose_name=_("Prefix"),
                              blank=True,
                              null=True)
    name = models.CharField(max_length=100,
                            verbose_name=_("Name"),
                            blank=True,
                            null=True)
    pre_name = models.CharField(max_length=100,
                                verbose_name=_("Pre-name"),
                                blank=True,
                                null=True)
    email = models.EmailField(max_length=200,
                              verbose_name=_("Email Address"))
    phone = models.CharField(max_length=20,
                             verbose_name=_("Phone Number"))
    role = models.CharField(max_length=100,
                            verbose_name=_("Role"),
                            blank=True,
                            null=True)
    companies = models.ManyToManyField("Contact",
                                       through='ContactPersonAssociation',
                                       verbose_name=_('Works at'), blank=True)

    def get_pre_name(self):
        if self.pre_name:
            return self.pre_name
        else:
            return "n/a"

    def get_name(self):
        if self.name:
            return self.name
        else:
            return "n/a"

    def get_email(self):
        if self.email:
            return self.email
        else:
            return "n/a"

    def __str__(self):
        return self.get_pre_name() + ' ' + self.get_name() + ' - ' + self.get_email()
    
    class Meta:
        app_label = "crm"
        verbose_name = _('Person')
        verbose_name_plural = _('People')



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-07-05 17:02
from __future__ import unicode_literals

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('accounting', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300, verbose_name='Name')),
                ('dateofcreation', models.DateTimeField(auto_now=True, verbose_name='Created at')),
                ('lastmodification', models.DateTimeField(auto_now_add=True, verbose_name='Last modified')),
            ],
            options={
                'verbose_name': 'Contact',
                'verbose_name_plural': 'Contact',
            },
        ),
        migrations.CreateModel(
            name='Contract',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.TextField(verbose_name='Description')),
                ('dateofcreation', models.DateTimeField(auto_now=True, verbose_name='Created at')),
                ('lastmodification', models.DateTimeField(auto_now_add=True, verbose_name='Last modified')),
            ],
            options={
                'verbose_name': 'Contract',
                'verbose_name_plural': 'Contracts',
            },
        ),
        migrations.CreateModel(
            name='Currency',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=100, verbose_name='Description')),
                (
                'shortName', models.CharField(max_length=3, verbose_name='Displayed Name After Price In The Position')),
                ('rounding',
                 models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Rounding')),
            ],
            options={
                'verbose_name': 'Currency',
                'verbose_name_plural': 'Currency',
            },
        ),
        migrations.CreateModel(
            name='CustomerBillingCycle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300, verbose_name='Name')),
                ('timeToPaymentDate', models.IntegerField(verbose_name='Days To Payment Date')),
            ],
            options={
                'verbose_name': 'Customer Billing Cycle',
                'verbose_name_plural': 'Customer Billing Cycle',
            },
        ),
        migrations.CreateModel(
            name='CustomerGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=300)),
            ],
            options={
                'verbose_name': 'Customer Group',
                'verbose_name_plural': 'Customer Groups',
            },
        ),
        migrations.CreateModel(
            name='CustomerGroupTransform',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('factor',
                 models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Customer Group')),
                ('fromCustomerGroup', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE,
                                                        related_name='db_reltransfromfromcustomergroup',
                                                        to='crm.CustomerGroup', verbose_name='From Unit')),
            ],
            options={
                'verbose_name': 'Customer Group Price Transfrom',
                'verbose_name_plural': 'Customer Group Price Transfroms',
            },
        ),
        migrations.CreateModel(
            name='EmailAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=200, verbose_name='Email Address')),
            ],
            options={
                'verbose_name': 'Email Address',
                'verbose_name_plural': 'Email Address',
            },
        ),
        migrations.CreateModel(
            name='PhoneAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone', models.CharField(max_length=20, verbose_name='Phone Number')),
            ],
            options={
                'verbose_name': 'Phone Address',
                'verbose_name_plural': 'Phone Address',
            },
        ),
        migrations.CreateModel(
            name='Position',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('positionNumber', models.IntegerField(verbose_name='Position Number')),
                ('quantity', models.DecimalField(decimal_places=3, max_digits=10, verbose_name='Quantity')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('discount',
                 models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount')),
                ('sentOn', models.DateField(blank=True, null=True, verbose_name='Shipment on')),
                ('shipmentID', models.CharField(blank=True, max_length=100, null=True, verbose_name='Shipment ID')),
                ('overwriteProductPrice', models.BooleanField(verbose_name='Overwrite Product Price')),
                ('positionPricePerUnit', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                             verbose_name='Price Per Unit')),
                ('lastPricingDate', models.DateField(blank=True, null=True, verbose_name='Last Pricing Date')),
                ('lastCalculatedPrice', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                            verbose_name='Last Calculted Price')),
                ('lastCalculatedTax', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                          verbose_name='Last Calculted Tax')),
            ],
            options={
                'verbose_name': 'Position',
                'verbose_name_plural': 'Positions',
            },
        ),
        migrations.CreateModel(
            name='PostalAddress',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('prefix',
                 models.CharField(blank=True, choices=[('F', 'Company'), ('W', 'Mrs'), ('H', 'Mr'), ('G', 'Ms')],
                                  max_length=1, null=True, verbose_name='Prefix')),
                ('name', models.CharField(blank=True, max_length=100, null=True, verbose_name='Name')),
                ('prename', models.CharField(blank=True, max_length=100, null=True, verbose_name='Prename')),
                ('addressline1', models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 1')),
                ('addressline2', models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 2')),
                ('addressline3', models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 3')),
                ('addressline4', models.CharField(blank=True, max_length=200, null=True, verbose_name='Addressline 4')),
                ('zipcode', models.IntegerField(blank=True, null=True, verbose_name='Zipcode')),
                ('town', models.CharField(blank=True, max_length=100, null=True, verbose_name='City')),
                ('state', models.CharField(blank=True, max_length=100, null=True, verbose_name='State')),
                ('country', models.CharField(blank=True,
                                             choices=[('AF', 'Afghanistan'), ('AX', 'Aland Islands'), ('AL', 'Albania'),
                                                      ('DZ', 'Algeria'), ('AS', 'American Samoa'), ('AD', 'Andorra'),
                                                      ('AO', 'Angola'), ('AI', 'Anguilla'), ('AQ', 'Antarctica'),
                                                      ('AG', 'Antigua and Barbuda'), ('AR', 'Argentina'),
                                                      ('AM', 'Armenia'), ('AW', 'Aruba'), ('AU', 'Australia'),
                                                      ('AT', 'Austria'), ('AZ', 'Azerbaijan'), ('BS', 'the Bahamas'),
                                                      ('BH', 'Bahrain'), ('BD', 'Bangladesh'), ('BB', 'Barbados'),
                                                      ('BY', 'Belarus'), ('BE', 'Belgium'), ('BZ', 'Belize'),
                                                      ('BJ', 'Benin'), ('BM', 'Bermuda'), ('BT', 'Bhutan'),
                                                      ('BO', 'Bolivia'), ('BA', 'Bosnia and Herzegovina'),
                                                      ('BW', 'Botswana'), ('BV', 'Bouvet Island'), ('BR', 'Brazil'),
                                                      ('IO', 'British Indian Ocean Territory'),
                                                      ('BN', 'Brunei Darussalam'), ('BG', 'Bulgaria'),
                                                      ('BF', 'Burkina Faso'), ('BI', 'Burundi'), ('KH', 'Cambodia'),
                                                      ('CM', 'Cameroon'), ('CA', 'Canada'), ('CV', 'Cape Verde'),
                                                      ('KY', 'Cayman Islands'), ('CF', 'Central African Republic'),
                                                      ('TD', 'Chad'), ('CL', 'Chile'), ('CN', 'China'),
                                                      ('CX', 'Christmas Island'), ('CC', 'Cocos (Keeling) Islands'),
                                                      ('CO', 'Colombia'), ('KM', 'Comoros'), ('CG', 'Congo'),
                                                      ('CD', 'Democratic Republic of the Congo'),
                                                      ('CK', 'Cook Islands'), ('CR', 'Costa Rica'),
                                                      ('CI', "Cote d'Ivoire"), ('HR', 'Croatia'), ('CU', 'Cuba'),
                                                      ('CY', 'Cyprus'), ('CZ', 'Czech Republic'), ('DK', 'Denmark'),
                                                      ('DJ', 'Djibouti'), ('DM', 'Dominica'),
                                                      ('DO', 'Dominican Republic'), ('EC', 'Ecuador'), ('EG', 'Egypt'),
                                                      ('SV', 'El Salvador'), ('GQ', 'Equatorial Guinea'),
                                                      ('ER', 'Eritrea'), ('EE', 'Estonia'), ('ET', 'Ethiopia'),
                                                      ('FK', 'Falkland Islands (Malvinas)'), ('FO', 'Faroe Islands'),
                                                      ('FJ', 'Fiji'), ('FI', 'Finland'), ('FR', 'France'),
                                                      ('GF', 'French Guiana'), ('PF', 'French Polynesia'),
                                                      ('TF', 'French Southern and Antarctic Lands'), ('GA', 'Gabon'),
                                                      ('GM', 'Gambia'), ('GE', 'Georgia'), ('DE', 'Germany'),
                                                      ('GH', 'Ghana'), ('GI', 'Gibraltar'), ('GR', 'Greece'),
                                                      ('GL', 'Greenland'), ('GD', 'Grenada'), ('GP', 'Guadeloupe'),
                                                      ('GU', 'Guam'), ('GT', 'Guatemala'), ('GG', 'Guernsey'),
                                                      ('GN', 'Guinea'), ('GW', 'Guinea-Bissau'), ('GY', 'Guyana'),
                                                      ('HT', 'Haiti'), ('HM', 'Heard Island and McDonald Islands'),
                                                      ('VA', 'Vatican City Holy See'), ('HN', 'Honduras'),
                                                      ('HK', 'Hong Kong'), ('HU', 'Hungary'), ('IS', 'Iceland'),
                                                      ('IN', 'India'), ('ID', 'Indonesia'), ('IR', 'Iran'),
                                                      ('IQ', 'Iraq'), ('IE', 'Ireland'), ('IM', 'Isle of Man'),
                                                      ('IL', 'Israel'), ('IT', 'Italy'), ('JM', 'Jamaica'),
                                                      ('JP', 'Japan'), ('JE', 'Jersey'), ('JO', 'Jordan'),
                                                      ('KZ', 'Kazakhstan'), ('KE', 'Kenya'), ('KI', 'Kiribati'),
                                                      ('KP', 'North Korea'), ('KR', 'South Korea'), ('KW', 'Kuwait'),
                                                      ('KG', 'Kyrgyzstan'), ('LA', 'Laos Lao'), ('LV', 'Latvia'),
                                                      ('LB', 'Lebanon'), ('LS', 'Lesotho'), ('LR', 'Liberia'),
                                                      ('LY', 'Libya Libyan Arab Jamahiriya'), ('LI', 'Liechtenstein'),
                                                      ('LT', 'Lithuania'), ('LU', 'Luxembourg'), ('MO', 'Macau Macao'),
                                                      ('MK', 'Macedonia'), ('MG', 'Madagascar'), ('MW', 'Malawi'),
                                                      ('MY', 'Malaysia'), ('MV', 'Maldives'), ('ML', 'Mali'),
                                                      ('MT', 'Malta'), ('MH', 'Marshall Islands'), ('MQ', 'Martinique'),
                                                      ('MR', 'Mauritania'), ('MU', 'Mauritius'), ('YT', 'Mayotte'),
                                                      ('MX', 'Mexico'), ('FM', 'Micronesia'), ('MD', 'Moldova'),
                                                      ('MC', 'Monaco'), ('MN', 'Mongolia'), ('ME', 'Montenegro'),
                                                      ('MS', 'Montserrat'), ('MA', 'Morocco'), ('MZ', 'Mozambique'),
                                                      ('MM', 'Myanmar'), ('NA', 'Namibia'), ('NR', 'Nauru'),
                                                      ('NP', 'Nepal'), ('NL', 'Netherlands'),
                                                      ('AN', 'Netherlands Antilles'), ('NC', 'New Caledonia'),
                                                      ('NZ', 'New Zealand'), ('NI', 'Nicaragua'), ('NE', 'Niger'),
                                                      ('NG', 'Nigeria'), ('NU', 'Niue'),
                                                      ('NF', 'Norfolk Island Norfolk Island'),
                                                      ('MP', 'Northern Mariana Islands'), ('NO', 'Norway'),
                                                      ('OM', 'Oman'), ('PK', 'Pakistan'), ('PW', 'Palau'),
                                                      ('PS', 'Palestinian Territory'), ('PA', 'Panama'),
                                                      ('PG', 'Papua New Guinea'), ('PY', 'Paraguay'), ('PE', 'Peru'),
                                                      ('PH', 'Philippines'), ('PN', 'Pitcairn Islands'),
                                                      ('PL', 'Poland'), ('PT', 'Portugal'), ('PR', 'Puerto Rico'),
                                                      ('QA', 'Qatar'), ('RE', 'Reunion'), ('RO', 'Romania'),
                                                      ('RU', 'Russia'), ('RW', 'Rwanda'), ('SH', 'Saint Helena'),
                                                      ('KN', 'Saint Kitts and Nevis'), ('LC', 'Saint Lucia'),
                                                      ('PM', 'Saint Pierre and Miquelon'),
                                                      ('VC', 'Saint Vincent and the Grenadines'), ('WS', 'Samoa'),
                                                      ('SM', 'San Marino'), ('ST', 'Sao Tome and Principe'),
                                                      ('SA', 'Saudi Arabia'), ('SN', 'Senegal'), ('RS', 'Serbia'),
                                                      ('SC', 'Seychelles'), ('SL', 'Sierra Leone'), ('SG', 'Singapore'),
                                                      ('SK', 'Slovakia'), ('SI', 'Slovenia'), ('SB', 'Solomon Islands'),
                                                      ('SO', 'Somalia'), ('ZA', 'South Africa'),
                                                      ('GS', 'South Georgia and the South Sandwich Islands'),
                                                      ('ES', 'Spain'), ('LK', 'Sri Lanka'), ('SD', 'Sudan'),
                                                      ('SR', 'Suriname'), ('SJ', 'Svalbard and Jan Mayen'),
                                                      ('SZ', 'Swaziland'), ('SE', 'Sweden'), ('CH', 'Switzerland'),
                                                      ('SY', 'Syria'), ('TW', 'Taiwan'), ('TJ', 'Tajikistan'),
                                                      ('TZ', 'Tanzania'), ('TH', 'Thailand'), ('TL', 'East Timor'),
                                                      ('TG', 'Togo'), ('TK', 'Tokelau'), ('TO', 'Tonga'),
                                                      ('TT', 'Trinidad and Tobago'), ('TN', 'Tunisia'),
                                                      ('TR', 'Turkey'), ('TM', 'Turkmenistan'),
                                                      ('TC', 'Turks and Caicos Islands'), ('TV', 'Tuvalu'),
                                                      ('UG', 'Uganda'), ('UA', 'Ukraine'),
                                                      ('AE', 'United Arab Emirates'), ('GB', 'United Kingdom'),
                                                      ('US', 'United States'),
                                                      ('UM', 'United States Minor Outlying Islands'), ('UY', 'Uruguay'),
                                                      ('UZ', 'Uzbekistan'), ('VU', 'Vanuatu'), ('VE', 'Venezuela'),
                                                      ('VN', 'Vietnam Viet Nam'), ('VG', 'British Virgin Islands'),
                                                      ('VI', 'United States Virgin Islands'),
                                                      ('WF', 'Wallis and Futuna'), ('EH', 'Western Sahara'),
                                                      ('YE', 'Yemen'), ('ZM', 'Zambia'), ('ZW', 'Zimbabwe')],
                                             max_length=2, null=True, verbose_name='Country')),
            ],
            options={
                'verbose_name': 'Postal Address',
                'verbose_name_plural': 'Postal Address',
            },
        ),
        migrations.CreateModel(
            name='Price',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.DecimalField(decimal_places=2, max_digits=17, verbose_name='Price Per Unit')),
                ('validfrom', models.DateField(blank=True, null=True, verbose_name='Valid from')),
                ('validuntil', models.DateField(blank=True, null=True, verbose_name='Valid until')),
                ('currency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency',
                                               verbose_name='Currency')),
                ('customerGroup', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                                    to='crm.CustomerGroup', verbose_name='Customer Group')),
            ],
            options={
                'verbose_name': 'Price',
                'verbose_name_plural': 'Prices',
            },
        ),
        migrations.CreateModel(
            name='Product',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.TextField(blank=True, null=True, verbose_name='Description')),
                ('title', models.CharField(max_length=200, verbose_name='Title')),
                ('productNumber', models.IntegerField(verbose_name='Product Number')),
                ('dateofcreation', models.DateTimeField(auto_now=True, verbose_name='Created at')),
                ('lastmodification', models.DateTimeField(auto_now_add=True, verbose_name='Last modified')),
                ('accoutingProductCategorie',
                 models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE,
                                   to='accounting.ProductCategorie', verbose_name='Accounting Product Categorie')),
            ],
            options={
                'verbose_name': 'Product',
                'verbose_name_plural': 'Products',
            },
        ),
        migrations.CreateModel(
            name='PurchaseOrder',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('externalReference',
                 models.CharField(blank=True, max_length=100, null=True, verbose_name='External Reference')),
                ('description', models.CharField(blank=True, max_length=100, null=True, verbose_name='Description')),
                ('lastPricingDate', models.DateField(blank=True, null=True, verbose_name='Last Pricing Date')),
                ('lastCalculatedPrice', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                            verbose_name='Last Calculted Price With Tax')),
                ('lastCalculatedTax', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                          verbose_name='Last Calculted Tax')),
                ('status', models.CharField(
                    choices=[('O', 'Ordered'), ('D', 'Delayed'), ('Y', 'Delivered'), ('I', 'Invoice registered'),
                             ('P', 'Invoice payed')], max_length=1)),
                ('dateofcreation', models.DateTimeField(auto_now=True, verbose_name='Created at')),
                ('lastmodification', models.DateTimeField(auto_now_add=True, verbose_name='Last modified')),
                ('contract', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract',
                                               verbose_name='Contract')),
                ('currency', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency',
                                               verbose_name='Currency')),
                ('lastmodifiedby',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_polstmodified',
                                   to=settings.AUTH_USER_MODEL, verbose_name='Last modified by')),
                ('staff', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                            related_name='db_relpostaff', to=settings.AUTH_USER_MODEL,
                                            verbose_name='Staff')),
            ],
            options={
                'verbose_name': 'Purchase Order',
                'verbose_name_plural': 'Purchase Order',
            },
        ),
        migrations.CreateModel(
            name='SalesContract',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('externalReference', models.CharField(blank=True, max_length=100, verbose_name='External Reference')),
                ('discount',
                 models.DecimalField(blank=True, decimal_places=2, max_digits=5, null=True, verbose_name='Discount')),
                ('description', models.CharField(blank=True, max_length=100, null=True, verbose_name='Description')),
                ('lastPricingDate', models.DateField(blank=True, null=True, verbose_name='Last Pricing Date')),
                ('lastCalculatedPrice', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                            verbose_name='Last Calculted Price With Tax')),
                ('lastCalculatedTax', models.DecimalField(blank=True, decimal_places=2, max_digits=17, null=True,
                                                          verbose_name='Last Calculted Tax')),
                ('dateofcreation', models.DateTimeField(auto_now=True, verbose_name='Created at')),
                ('lastmodification', models.DateTimeField(auto_now_add=True, verbose_name='Last modified')),
            ],
            options={
                'verbose_name': 'Sales Contract',
                'verbose_name_plural': 'Sales Contracts',
            },
        ),
        migrations.CreateModel(
            name='Tax',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('taxrate', models.DecimalField(decimal_places=2, max_digits=5, verbose_name='Taxrate in Percentage')),
                ('name', models.CharField(max_length=100, verbose_name='Taxname')),
                ('accountActiva', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                                    related_name='db_relaccountactiva', to='accounting.Account',
                                                    verbose_name='Activa Account')),
                ('accountPassiva', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                                     related_name='db_relaccountpassiva', to='accounting.Account',
                                                     verbose_name='Passiva Account')),
            ],
            options={
                'verbose_name': 'Tax',
                'verbose_name_plural': 'Taxes',
            },
        ),
        migrations.CreateModel(
            name='Unit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('description', models.CharField(max_length=100, verbose_name='Description')),
                ('shortName',
                 models.CharField(max_length=3, verbose_name='Displayed Name After Quantity In The Position')),
                ('fractionFactorToNextHigherUnit',
                 models.IntegerField(blank=True, null=True, verbose_name='Factor Between This And Next Higher Unit')),
                ('isAFractionOf',
                 models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit',
                                   verbose_name='Is A Fraction Of')),
            ],
            options={
                'verbose_name': 'Unit',
                'verbose_name_plural': 'Units',
            },
        ),
        migrations.CreateModel(
            name='UnitTransform',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('factor', models.IntegerField(blank=True, null=True, verbose_name='Factor between From and To Unit')),
                ('fromUnit',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromfromunit',
                                   to='crm.Unit', verbose_name='From Unit')),
                ('product', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product',
                                              verbose_name='Product')),
                ('toUnit',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltransfromtounit',
                                   to='crm.Unit', verbose_name='To Unit')),
            ],
            options={
                'verbose_name': 'Unit Transfrom',
                'verbose_name_plural': 'Unit Transfroms',
            },
        ),
        migrations.CreateModel(
            name='Customer',
            fields=[
                ('contact_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.Contact')),
                ('defaultCustomerBillingCycle',
                 models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.CustomerBillingCycle',
                                   verbose_name='Default Billing Cycle')),
                ('ismemberof', models.ManyToManyField(blank=True, to='crm.CustomerGroup', verbose_name='Is member of')),
            ],
            options={
                'verbose_name': 'Customer',
                'verbose_name_plural': 'Customers',
            },
            bases=('crm.contact',),
        ),
        migrations.CreateModel(
            name='EmailAddressForContact',
            fields=[
                ('emailaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.EmailAddress')),
                ('purpose', models.CharField(
                    choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Email Address For Contact',
                'verbose_name_plural': 'Email Address For Contact',
            },
            bases=('crm.emailaddress',),
        ),
        migrations.CreateModel(
            name='EmailAddressForContract',
            fields=[
                ('emailaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.EmailAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Email Address For Contracts',
                'verbose_name_plural': 'Email Address For Contracts',
            },
            bases=('crm.emailaddress',),
        ),
        migrations.CreateModel(
            name='EmailAddressForPurchaseOrder',
            fields=[
                ('emailaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.EmailAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Email Address For Contracts',
                'verbose_name_plural': 'Email Address For Contracts',
            },
            bases=('crm.emailaddress',),
        ),
        migrations.CreateModel(
            name='EmailAddressForSalesContract',
            fields=[
                ('emailaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.EmailAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Email Address For Contracts',
                'verbose_name_plural': 'Email Address For Contracts',
            },
            bases=('crm.emailaddress',),
        ),
        migrations.CreateModel(
            name='Invoice',
            fields=[
                ('salescontract_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.SalesContract')),
                ('payableuntil', models.DateField(verbose_name='To pay until')),
                ('paymentBankReference',
                 models.CharField(blank=True, max_length=100, null=True, verbose_name='Payment Bank Reference')),
                ('status', models.CharField(choices=[('P', 'Payed'), ('C', 'Invoice created'), ('I', 'Invoice sent'),
                                                     ('F', 'First reminder sent'), ('R', 'Second reminder sent'),
                                                     ('U', 'Customer cant pay'), ('D', 'Deleted')], max_length=1)),
            ],
            options={
                'verbose_name': 'Invoice',
                'verbose_name_plural': 'Invoices',
            },
            bases=('crm.salescontract',),
        ),
        migrations.CreateModel(
            name='PhoneAddressForContact',
            fields=[
                ('phoneaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PhoneAddress')),
                ('purpose', models.CharField(
                    choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Phone Address For Contact',
                'verbose_name_plural': 'Phone Address For Contact',
            },
            bases=('crm.phoneaddress',),
        ),
        migrations.CreateModel(
            name='PhoneAddressForContract',
            fields=[
                ('phoneaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PhoneAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Phone Address For Contracts',
                'verbose_name_plural': 'Phone Address For Contracts',
            },
            bases=('crm.phoneaddress',),
        ),
        migrations.CreateModel(
            name='PhoneAddressForPurchaseOrder',
            fields=[
                ('phoneaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PhoneAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Phone Address For Contracts',
                'verbose_name_plural': 'Phone Address For Contracts',
            },
            bases=('crm.phoneaddress',),
        ),
        migrations.CreateModel(
            name='PhoneAddressForSalesContract',
            fields=[
                ('phoneaddress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PhoneAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Phone Address For Contracts',
                'verbose_name_plural': 'Phone Address For Contracts',
            },
            bases=('crm.phoneaddress',),
        ),
        migrations.CreateModel(
            name='PostalAddressForContact',
            fields=[
                ('postaladdress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PostalAddress')),
                ('purpose', models.CharField(
                    choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Postal Address For Contact',
                'verbose_name_plural': 'Postal Address For Contact',
            },
            bases=('crm.postaladdress',),
        ),
        migrations.CreateModel(
            name='PostalAddressForContract',
            fields=[
                ('postaladdress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PostalAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Postal Address For Contracts',
                'verbose_name_plural': 'Postal Address For Contracts',
            },
            bases=('crm.postaladdress',),
        ),
        migrations.CreateModel(
            name='PostalAddressForPurchaseOrder',
            fields=[
                ('postaladdress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PostalAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Postal Address For Contracts',
                'verbose_name_plural': 'Postal Address For Contracts',
            },
            bases=('crm.postaladdress',),
        ),
        migrations.CreateModel(
            name='PostalAddressForSalesContract',
            fields=[
                ('postaladdress_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.PostalAddress')),
                ('purpose', models.CharField(
                    choices=[('D', 'Delivery Address'), ('B', 'Billing Address'), ('C', 'Contact Address')],
                    max_length=1, verbose_name='Purpose')),
            ],
            options={
                'verbose_name': 'Postal Address For Contracts',
                'verbose_name_plural': 'Postal Address For Contracts',
            },
            bases=('crm.postaladdress',),
        ),
        migrations.CreateModel(
            name='PurchaseOrderPosition',
            fields=[
                ('position_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.Position')),
                ('contract', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder',
                                               verbose_name='Contract')),
            ],
            options={
                'verbose_name': 'Purchaseorder Position',
                'verbose_name_plural': 'Purchaseorder Positions',
            },
            bases=('crm.position',),
        ),
        migrations.CreateModel(
            name='Quote',
            fields=[
                ('salescontract_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.SalesContract')),
                ('validuntil', models.DateField(verbose_name='Valid until')),
                ('status', models.CharField(choices=[('S', 'Success'), ('I', 'Quote created'), ('Q', 'Quote sent'),
                                                     ('F', 'First reminder sent'), ('R', 'Second reminder sent'),
                                                     ('D', 'Deleted')], max_length=1, verbose_name='Status')),
            ],
            options={
                'verbose_name': 'Quote',
                'verbose_name_plural': 'Quotes',
            },
            bases=('crm.salescontract',),
        ),
        migrations.CreateModel(
            name='SalesContractPosition',
            fields=[
                ('position_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.Position')),
            ],
            options={
                'verbose_name': 'Salescontract Position',
                'verbose_name_plural': 'Salescontract Positions',
            },
            bases=('crm.position',),
        ),
        migrations.CreateModel(
            name='Supplier',
            fields=[
                ('contact_ptr',
                 models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True,
                                      primary_key=True, serialize=False, to='crm.Contact')),
                ('offersShipmentToCustomers', models.BooleanField(verbose_name='Offers Shipment to Customer')),
            ],
            options={
                'verbose_name': 'Supplier',
                'verbose_name_plural': 'Supplier',
            },
            bases=('crm.contact',),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract',
                                    verbose_name='Contract'),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='currency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency',
                                    verbose_name='Currency'),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_lstscmodified', to=settings.AUTH_USER_MODEL,
                                    verbose_name='Last modified by'),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_relscstaff', to=settings.AUTH_USER_MODEL, verbose_name='Staff'),
        ),
        migrations.AddField(
            model_name='product',
            name='defaultunit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AddField(
            model_name='product',
            name='lastmodifiedby',
            field=models.ForeignKey(blank='True', null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AddField(
            model_name='product',
            name='tax',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Tax'),
        ),
        migrations.AddField(
            model_name='price',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product',
                                    verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='price',
            name='unit',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Unit', verbose_name='Unit'),
        ),
        migrations.AddField(
            model_name='position',
            name='product',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='crm.Product', verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='position',
            name='unit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Unit',
                                    verbose_name='Unit'),
        ),
        migrations.AddField(
            model_name='customergrouptransform',
            name='product',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Product',
                                    verbose_name='Product'),
        ),
        migrations.AddField(
            model_name='customergrouptransform',
            name='toCustomerGroup',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_reltransfromtocustomergroup', to='crm.CustomerGroup',
                                    verbose_name='To Unit'),
        ),
        migrations.AddField(
            model_name='contract',
            name='defaultcurrency',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Currency',
                                    verbose_name='Default Currency'),
        ),
        migrations.AddField(
            model_name='contract',
            name='lastmodifiedby',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_contractlstmodified',
                                    to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AddField(
            model_name='contract',
            name='staff',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    related_name='db_relcontractstaff', to=settings.AUTH_USER_MODEL,
                                    verbose_name='Staff'),
        ),
        migrations.AddField(
            model_name='contact',
            name='lastmodifiedby',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE,
                                    to=settings.AUTH_USER_MODEL, verbose_name='Last modified by'),
        ),
        migrations.AddField(
            model_name='salescontractposition',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract',
                                    verbose_name='Contract'),
        ),
        migrations.AddField(
            model_name='salescontract',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Customer',
                                    verbose_name='Customer'),
        ),
        migrations.AddField(
            model_name='purchaseorder',
            name='supplier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Supplier',
                                    verbose_name='Supplier'),
        ),
        migrations.AddField(
            model_name='postaladdressforsalescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract'),
        ),
        migrations.AddField(
            model_name='postaladdressforpurchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder'),
        ),
        migrations.AddField(
            model_name='postaladdressforcontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract'),
        ),
        migrations.AddField(
            model_name='postaladdressforcontact',
            name='person',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contact'),
        ),
        migrations.AddField(
            model_name='position',
            name='supplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='crm.Supplier', verbose_name='Shipment Supplier'),
        ),
        migrations.AddField(
            model_name='phoneaddressforsalescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract'),
        ),
        migrations.AddField(
            model_name='phoneaddressforpurchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder'),
        ),
        migrations.AddField(
            model_name='phoneaddressforcontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract'),
        ),
        migrations.AddField(
            model_name='phoneaddressforcontact',
            name='person',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contact'),
        ),
        migrations.AddField(
            model_name='invoice',
            name='derivatedFromQuote',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='crm.Quote'),
        ),
        migrations.AddField(
            model_name='emailaddressforsalescontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.SalesContract'),
        ),
        migrations.AddField(
            model_name='emailaddressforpurchaseorder',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.PurchaseOrder'),
        ),
        migrations.AddField(
            model_name='emailaddressforcontract',
            name='contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contract'),
        ),
        migrations.AddField(
            model_name='emailaddressforcontact',
            name='person',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='crm.Contact'),
        ),
        migrations.AddField(
            model_name='contract',
            name='defaultSupplier',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='crm.Supplier', verbose_name='Default Supplier'),
        ),
        migrations.AddField(
            model_name='contract',
            name='defaultcustomer',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE,
                                    to='crm.Customer', verbose_name='Default Customer'),
        ),
    ]



# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext as _
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.contrib import admin


class GenericTaskLink(models.Model):
    task = models.ForeignKey("Task",
                             on_delete=models.CASCADE,
                             verbose_name=_('Task'),
                             blank=False, null=False)
    task_link_type = models.ForeignKey("TaskLinkType",
                                       on_delete=models.CASCADE,
                                       verbose_name=_('Task Link Type'),
                                       blank=True,
                                       null=True)
    content_type = models.ForeignKey(ContentType,
                                     on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    generic_crm_object = GenericForeignKey('content_type',
                                           'object_id')
    date_of_creation = models.DateTimeField(verbose_name=_("Created at"),
                                            auto_now_add=True)
    last_modified_by = models.ForeignKey('auth.User',
                                         on_delete=models.CASCADE,
                                         limit_choices_to={'is_staff': True},
                                         verbose_name=_("Last modified by"),
                                         related_name="db_task_link_last_modified")

    def __str__(self):
        return str(self.id)

    class Meta:
        app_label = "crm"
        verbose_name = _('Task Link')
        verbose_name_plural = _('Task Links')


class InlineGenericTaskLink(admin.TabularInline):
    model = GenericTaskLink
    readonly_fields = ('task_link_type',
                       'content_type',
                       'object_id',
                       'date_of_creation',
                       'last_modified_by')
    extra = 0

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False



# -*- coding: utf-8 -*-

from datetime import *
from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _
from django.utils import timezone
from koalixcrm.crm.const.status import *


class Call(models.Model):
    staff = models.ForeignKey('auth.User',
                              on_delete=models.CASCADE,
                              limit_choices_to={'is_staff': True},
                              verbose_name=_("Staff"),
                              related_name="db_relcallstaff",
                              blank=True,
                              null=True)
    description = models.TextField(verbose_name=_("Description"))
    date_of_creation = models.DateTimeField(verbose_name=_("Created at"),
                                            auto_now_add=True)
    date_due = models.DateTimeField(verbose_name=_("Date due"),
                                    default=datetime.now,
                                    blank=True)
    last_modification = models.DateTimeField(verbose_name=_("Last modified"),
                                             auto_now=True)
    last_modified_by = models.ForeignKey('auth.User',
                                         on_delete=models.CASCADE,
                                         limit_choices_to={'is_staff': True},
                                         blank=True,
                                         null=True,
                                         verbose_name=_("Last modified by"),
                                         related_name="db_calllstmodified")
    status = models.CharField(verbose_name=_("Status"),
                              max_length=1,
                              choices=CALLSTATUS,
                              default="P")

    def __str__(self):
        return _("Call") + " " + str(self.id)


class CallOverdueFilter(admin.SimpleListFilter):
    title = _('Is call overdue')
    parameter_name = 'date_due'

    def lookups(self, request, model_admin):
        return (
            ('overdue', _('Overdue')),
            ('planned', _('Planned')),
        )

    def queryset(self, request, queryset):
        if self.value() == 'planned':
            return queryset.filter(date_due__gt=timezone.now())
        elif self.value() == 'overdue':
            return queryset.filter(date_due__lt=timezone.now()).exclude(status__in=['F', 'S'])
        else:
            return queryset


class OptionCall(admin.ModelAdmin):
    list_display = ('id',
                    'description',
                    'date_due',
                    'purpose',
                    'status',
                    'cperson',
                    'is_call_overdue',
                    'get_contact_name')
    fieldsets = (('', {'fields': ('staff',
                                  'description',
                                  'date_due',
                                  'purpose',
                                  'company',
                                  'cperson',
                                  'status')}),)
    list_filter = [CallOverdueFilter]

    @staticmethod
    def get_contact_name(obj):
        return obj.company.name

    get_contact_name.short_description = _("Company")

    @staticmethod
    def is_call_overdue(obj):
        if obj.date_due < timezone.now() and obj.status not in ['F', 'S']:
            overdue = True
        else:
            overdue = False
        return overdue

    is_call_overdue.short_description = _("Is call overdue")


class OptionVisit(admin.ModelAdmin):
    list_display = ('id',
                    'description',
                    'cperson',
                    'date_due',
                    'purpose',
                    'get_contact_name',
                    'status',
                    'ref_call',)
    fieldsets = (('', {'fields': ('staff',
                                  'description',
                                  'date_due',
                                  'purpose',
                                  'company',
                                  'cperson',
                                  'status')}),)

    @staticmethod
    def get_contact_name(obj):
        return obj.company.name

    get_contact_name.short_description = _("Company")



# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext as _
from koalixcrm.crm.const.country import *
from koalixcrm.crm.const.postaladdressprefix import *


class PostalAddress(models.Model):
    prefix = models.CharField(max_length=1,
                              choices=POSTALADDRESSPREFIX,
                              verbose_name=_("Prefix"), blank=True,
                              null=True)
    name = models.CharField(max_length=100,
                            verbose_name=_("Name"),
                            blank=True,
                            null=True)
    pre_name = models.CharField(max_length=100,
                                verbose_name=_("Pre-name"),
                                blank=True,
                                null=True)
    address_line_1 = models.CharField(max_length=200,
                                      verbose_name=_("Address line 1"),
                                      blank=True,
                                      null=True)
    address_line_2 = models.CharField(max_length=200,
                                      verbose_name=_("Address line 2"),
                                      blank=True,
                                      null=True)
    address_line_3 = models.CharField(max_length=200,
                                      verbose_name=_("Address line 3"),
                                      blank=True,
                                      null=True)
    address_line_4 = models.CharField(max_length=200,
                                      verbose_name=_("Address line 4"),
                                      blank=True,
                                      null=True)
    zip_code = models.IntegerField(verbose_name=_("Zip Code"),
                                   blank=True,
                                   null=True)
    town = models.CharField(max_length=100,
                            verbose_name=_("City"),
                            blank=True,
                            null=True)
    state = models.CharField(max_length=100,
                             verbose_name=_("State"),
                             blank=True,
                             null=True)
    country = models.CharField(max_length=2,
                               choices=[(x[0], x[3]) for x in COUNTRIES],
                               verbose_name=_("Country"),
                               blank=True,
                               null=True)

    class Meta:
        app_label = "crm"
        verbose_name = _('Postal Address')
        verbose_name_plural = _('Postal Address')



# -*- coding: utf-8 -*-

from datetime import *
from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _
from koalixcrm.crm.documents.pdf_export import PDFExport
from koalixcrm.crm.exceptions import ReportingPeriodNotFound
from koalixcrm.crm.reporting.work import WorkInlineAdminView
from rest_framework import serializers
from django.core.exceptions import ValidationError
from django.forms import ModelForm


class ReportingPeriod(models.Model):
    """The reporting period is referred in the work, in the expenses and purchase orders, it is used as a
       supporting object to generate project reports"""
    project = models.ForeignKey("Project",
                                on_delete=models.CASCADE,
                                verbose_name=_("Project"),
                                blank=False,
                                null=False)
    title = models.CharField(max_length=200,
                             verbose_name=_("Title"),
                             blank=False,
                             null=False)  # For example "March 2018", "1st Quarter 2019"
    begin = models.DateField(verbose_name=_("Begin"),
                             blank=False,
                             null=False)
    end = models.DateField(verbose_name=_("End"),
                           blank=False,
                           null=False)
    status = models.ForeignKey("ReportingPeriodStatus",
                               on_delete=models.CASCADE,
                               verbose_name=_("Reporting Period Status"),
                               blank=True,
                               null=True)

    @staticmethod
    def get_reporting_period(project, search_date):
        """Returns the reporting period that is currently valid. Valid is a reporting period when the provided date
          lies between begin and end of the reporting period

        Args:
          no arguments

        Returns:
          reporting_period (ReportPeriod)

        Raises:
          ReportPeriodNotFound when there is no valid reporting Period"""
        current_valid_reporting_period = None
        for reporting_period in ReportingPeriod.objects.filter(project=project):
            if reporting_period.begin <= search_date <= reporting_period.end:
                return reporting_period
        if not current_valid_reporting_period:
            raise ReportingPeriodNotFound("Reporting Period does not exist")

    @staticmethod
    def get_latest_reporting_period(project):
        """Returns the latest reporting period

        Args:
          no arguments

        Returns:
          reporting_period (ReportPeriod)

        Raises:
          ReportPeriodNotFound when there is no valid reporting Period"""
        latest_reporting_period = None
        reporting_periods = ReportingPeriod.objects.filter(project=project)
        for reporting_period in reporting_periods:
            if latest_reporting_period is None:
                latest_reporting_period = reporting_period
            else:
                if latest_reporting_period.end <= reporting_period.begin:
                    latest_reporting_period = reporting_period
        if not latest_reporting_period:
            raise ReportingPeriodNotFound("Reporting Period does not exist")
        return latest_reporting_period

    @staticmethod
    def get_predecessor(target_reporting_period, project):
        """Returns the reporting period which was valid right before the provided target_reporting_period

        Args:
          no arguments

        Returns:
          predecessor_reporting_period (ReportPeriod)

        Raises:
          ReportPeriodNotFound when there is no valid reporting Period"""
        predecessor_reporting_period = None
        reporting_periods = ReportingPeriod.objects.filter(project=project)
        for reporting_period in reporting_periods:
            if reporting_period.end <= target_reporting_period.begin and\
                    predecessor_reporting_period is None:
                predecessor_reporting_period = reporting_period
            elif reporting_period.end <= target_reporting_period.begin and \
                    predecessor_reporting_period.end <= reporting_period.begin:
                predecessor_reporting_period = reporting_period
        if predecessor_reporting_period is None:
            raise ReportingPeriodNotFound("Reporting Period does not exist")
        return predecessor_reporting_period

    @staticmethod
    def get_all_predecessors(target_reporting_period, project):
        """Returns all reporting periods which have been valid before the provided target_reporting_period

        Args:
          no arguments

        Returns:
          predecessor_reporting_periods[] (Array of ReportPeriod)

        Raises:
          ReportPeriodNotFound when there is no valid reporting Period"""
        predecessor_reporting_periods = list()
        reporting_periods = ReportingPeriod.objects.filter(project=project)
        for reporting_period in reporting_periods:
            if reporting_period.end <= target_reporting_period.begin:
                predecessor_reporting_periods.append(reporting_period)
        return predecessor_reporting_periods

    def is_reporting_allowed(self):
        """Returns True when the reporting period is available for reporting,
        Returns False when the reporting period is not available for reporting,
        The decision whether the reporting period is available for reporting is purely depending
        on the reporting_period_status. When the status is done, the reporting period is not longer
        available for reporting. In all other cases the reporting is allowed.

        Args:
          no arguments

        Returns:
          allowed (Boolean)

        Raises:
           when there is no valid reporting Period"""
        if self.status:
            if self.status.is_done:
                allowed = False
            else:
                allowed = True
        else:
            allowed = False
        return allowed

    def create_pdf(self, template_set, printed_by):
        self.last_print_date = datetime.now()
        self.save()
        return PDFExport.create_pdf(self, template_set, printed_by)

    def get_template_set(self):
        return self.project.get_template_set()

    def get_fop_config_file(self, template_set):
        return self.project.get_fop_config_file(template_set=None)

    def get_xsl_file(self, template_set):
        return self.project.get_xsl_file(template_set=None)

    def serialize_to_xml(self):
        objects = [self, ]
        main_xml = PDFExport.write_xml(objects)
        project_xml = self.project.serialize_to_xml(reporting_period=self)
        main_xml = PDFExport.merge_xml(main_xml, project_xml)
        return main_xml

    def __str__(self):
        return str(self.id)+" "+self.title

    class Meta:
        app_label = "crm"
        verbose_name = _('Reporting Period')
        verbose_name_plural = _('Reporting Periods')


class ReportingPeriodAdminForm(ModelForm):
    def clean(self):
        """Check that the begin of the new reporting period is not located within an existing
        reporting period, Checks that the begin date earlier than the end date. Verify that in case there
        is already a predecessor or a successor reporting period, the reporting periods are in direct contact
        with each other"""
        cleaned_data = super().clean()
        project = cleaned_data['project']
        end = cleaned_data['end']
        begin = cleaned_data['begin']
        reporting_periods = ReportingPeriod.objects.filter(project=project)
        for reporting_period in reporting_periods:
            if reporting_period.pk != self.instance.pk:
                if (begin < reporting_period.end) and (begin > reporting_period.begin):
                    raise ValidationError('The Reporting Period overlaps with an existing '
                                          'Reporting Period within the same project')
                if (end < reporting_period.end) and (end > reporting_period.begin):
                    raise ValidationError('The Reporting Period overlaps with an existing '
                                          'Reporting Period within the same project')
        if end < begin:
            raise ValidationError('Begin date must be earlier than end date')
        if len(reporting_periods) > 1:
            reporting_periods_direct_predecessor = ReportingPeriod.objects.filter(project=project,
                                                                                  end=begin-timedelta(1))
            reporting_periods_direct_successor = ReportingPeriod.objects.filter(project=project,
                                                                                begin=end+timedelta(1))
            if (len(reporting_periods_direct_predecessor) == 0) and (len(reporting_periods_direct_successor) == 0):
                raise ValidationError('The new reporting period has to be directly following a previous reporting '
                                      'period or it has to be directly before the following reporting period')


class ReportingPeriodAdmin(admin.ModelAdmin):
    form = ReportingPeriodAdminForm
    list_display = ('id',
                    'project',
                    'title',
                    'begin',
                    'end',
                    'status')

    list_display_links = ('id',)
    ordering = ('-id',)

    fieldsets = (
        (_('ReportingPeriod'), {
            'fields': ('project',
                       'title',
                       'begin',
                       'end',
                       'status')
        }),
    )

    inlines = [WorkInlineAdminView, ]
    actions = ['create_report_pdf', ]

    def save_model(self, request, obj, form, change):
        if change:
            obj.last_modified_by = request.user
        else:
            obj.last_modified_by = request.user
            obj.staff = request.user
        obj.save()

    def create_report_pdf(self, request, queryset):
        from koalixcrm.crm.views.pdfexport import PDFExportView
        for obj in queryset:
            response = PDFExportView.export_pdf(self,
                                                request,
                                                obj,
                                                ("/admin/crm/"+obj.__class__.__name__.lower()+"/"),
                                                obj.project.default_template_set.monthly_project_summary_template)
            return response

    create_report_pdf.short_description = _("Create Report PDF")


class ReportingPeriodInlineAdminView(admin.TabularInline):
    model = ReportingPeriod
    fieldsets = (
        (_('ReportingPeriod'), {
            'fields': ('project',
                       'title',
                       'begin',
                       'end',
                       'status')
        }),
    )

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False


class ProjectJSONSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = ReportingPeriod
        fields = ('id',
                  'project',
                  'title',
                  'begin',
                  'end')



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-10 17:32
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import filebrowser.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djangoUserExtension', '0002_auto_20171009_1949'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='templateset',
            options={'verbose_name': 'Templateset', 'verbose_name_plural': 'Templatesets'},
        ),
        migrations.AlterModelOptions(
            name='userextension',
            options={'verbose_name': 'User Extention', 'verbose_name_plural': 'User Extentions'},
        ),
        migrations.AlterModelOptions(
            name='xslfile',
            options={'verbose_name': 'XSL File', 'verbose_name_plural': 'XSL Files'},
        ),
        migrations.AddField(
            model_name='templateset',
            name='reminder1XSLFile',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepaymentreminder1', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Payment Reminder 1'),
        ),
        migrations.AddField(
            model_name='templateset',
            name='reminder2XSLFile',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepaymentreminder2', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Payment Reminder 2'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='addresser',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='Addresser'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='balancesheetXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatebalancesheet', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Balancesheet'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='bankingaccountref',
            field=models.CharField(blank=True, max_length=60, null=True, verbose_name='Reference to Banking Account'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='deilveryorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatedeliveryorder', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Deilvery Order'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Footer Text On Purchaseorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='footerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Footer Text On Salesorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='fopConfigurationFile',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='FOP Configuration File'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextpurchaseorders',
            field=models.TextField(blank=True, null=True, verbose_name='Header Text On Purchaseorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='headerTextsalesorders',
            field=models.TextField(blank=True, null=True, verbose_name='Header Text On Salesorders'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='invoiceXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateinvoice', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Invoice'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='logo',
            field=filebrowser.fields.FileBrowseField(blank=True, max_length=200, null=True, verbose_name='Logo for the PDF generation'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='organisationname',
            field=models.CharField(max_length=200, verbose_name='Name of the Organisation'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefooterleft',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Page Footer Left'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='pagefootermiddle',
            field=models.CharField(blank=True, max_length=40, null=True, verbose_name='Page Footer Middle'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='profitLossStatementXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplateprofitlossstatement', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Profit Loss Statement'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='purchaseorderXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatepurchaseorder', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Purchaseorder'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='quoteXSLFile',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_reltemplatequote', to='djangoUserExtension.XSLFile', verbose_name='XSL File for Quote'),
        ),
        migrations.AlterField(
            model_name='templateset',
            name='title',
            field=models.CharField(max_length=100, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='userextensionemailaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='userextensionphoneaddress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='userextensionpostaladdress',
            name='purpose',
            field=models.CharField(choices=[('H', 'Private'), ('O', 'Business'), ('P', 'Mobile Private'), ('B', 'Mobile Business')], max_length=1, verbose_name='Purpose'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='title',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Title'),
        ),
        migrations.AlterField(
            model_name='xslfile',
            name='xslfile',
            field=filebrowser.fields.FileBrowseField(max_length=200, verbose_name='XSL File'),
        ),
    ]



from rest_framework import serializers
from koalixcrm.crm.reporting.reporting_period_status import ReportingPeriodStatus


class OptionReportingPeriodStatusJSONSerializer(serializers.HyperlinkedModelSerializer):
    title = serializers.CharField(source='title', read_only=True)
    description = serializers.CharField(source='description', read_only=True)
    isDone = serializers.BooleanField(source='is_done', read_only=True)

    class Meta:
        model = ReportingPeriodStatus
        fields = ('title',
                  'description',
                  'is_done')


class ReportingPeriodStatusJSONSerializer(serializers.HyperlinkedModelSerializer):
    title = serializers.CharField(source='title')
    description = serializers.CharField(source='description')
    isDone = serializers.BooleanField(source='is_done')

    class Meta:
        model = ReportingPeriodStatus
        fields = ('title',
                  'description',
                  'is_done')



# -*- coding: utf-8 -*-
import pytz
from django.utils import timezone


class TimezoneMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        tzname = request.session.get('django_timezone')
        if tzname:
            timezone.activate(pytz.timezone(tzname))
        else:
            timezone.deactivate()
        return self.get_response(request)


# -*- coding: utf-8 -*-

from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _

from koalixcrm.global_support_functions import xstr
from koalixcrm.crm.exceptions import *


class TemplateSet(models.Model):
    title = models.CharField(verbose_name=_("Title"),
                             max_length=100)
    invoice_template = models.ForeignKey("InvoiceTemplate",
                                         on_delete=models.CASCADE,
                                         blank=True,
                                         null=True)
    quote_template = models.ForeignKey("QuoteTemplate",
                                       on_delete=models.CASCADE,
                                       blank=True,
                                       null=True)
    delivery_note_template = models.ForeignKey("DeliveryNoteTemplate",
                                               on_delete=models.CASCADE,
                                               blank=True, null=True)
    payment_reminder_template = models.ForeignKey("PaymentReminderTemplate",
                                                  on_delete=models.CASCADE,
                                                  blank=True,
                                                  null=True)
    purchase_confirmation_template = models.ForeignKey("PurchaseConfirmationTemplate",
                                                       on_delete=models.CASCADE,
                                                       blank=True, null=True)
    purchase_order_template = models.ForeignKey("PurchaseOrderTemplate",
                                                on_delete=models.CASCADE,
                                                blank=True,
                                                null=True)
    profit_loss_statement_template = models.ForeignKey("ProfitLossStatementTemplate",
                                                       on_delete=models.CASCADE,
                                                       blank=True, null=True)
    balance_sheet_statement_template = models.ForeignKey("BalanceSheetTemplate",
                                                         on_delete=models.CASCADE,
                                                         blank=True,
                                                         null=True)
    monthly_project_summary_template = models.ForeignKey("MonthlyProjectSummaryTemplate",
                                                         on_delete=models.CASCADE,
                                                         blank=True,
                                                         null=True)
    work_report_template = models.ForeignKey("WorkReportTemplate",
                                             on_delete=models.CASCADE,
                                             blank=True,
                                             null=True)

    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Template-set')
        verbose_name_plural = _('Template-sets')

    def __str__(self):
        return xstr(self.id) + ' ' + xstr(self.title)

    def get_template_set(self, required_template_set):
        mapping_class_to_templates = {"Invoice": self.invoice_template,
                                      "Quote": self.quote_template,
                                      "DeliveryNote": self.delivery_note_template,
                                      "PaymentReminder": self.payment_reminder_template,
                                      "PurchaseConfirmation": self.purchase_confirmation_template,
                                      "PurchaseOrder": self.purchase_order_template,
                                      "ProfitLossStatement": self.profit_loss_statement_template,
                                      "BalanceSheet": self.balance_sheet_statement_template,
                                      "MonthlyProjectSummaryTemplate": self.monthly_project_summary_template,
                                      "WorkReport": self.work_report_template}
        try:
            if mapping_class_to_templates[required_template_set]:
                return mapping_class_to_templates[required_template_set]
            else:
                raise TemplateMissingInTemplateSet("The TemplateSet does not contain a template for " +
                                                   required_template_set)
        except KeyError:
            raise IncorrectUseOfAPI("")


class OptionTemplateSet(admin.ModelAdmin):
    list_display = ('id', 'title')
    list_display_links = ('id', 'title')
    ordering = ('id',)
    search_fields = ('id', 'title')
    fieldsets = (
        (_('Basics'), {
            'fields': ('title',
                       'invoice_template',
                       'quote_template',
                       'delivery_note_template',
                       'payment_reminder_template',
                       'purchase_confirmation_template',
                       'purchase_order_template',
                       'profit_loss_statement_template',
                       'balance_sheet_statement_template',
                       'monthly_project_summary_template',
                       'work_report_template')
        }),
    )



# -*- coding: utf-8 -*-
from django.http import Http404
from django.http import HttpResponseRedirect
from django.utils.translation import ugettext as _
from django.contrib import messages
from koalixcrm.crm.exceptions import *


class CreateNewDocumentView:
    def create_new_document(calling_model_admin, request, calling_model, requested_document_type, redirect_to):
        """This method exports PDFs provided by different Models in the crm application

            Args:
              calling_model_admin (ModelAdmin):  The calling ModelAdmin must be provided for error message response.
              request: The request User is to know where to save the error message
              calling_model (Contract or SalesDocument):  The model from which a new document shall be created
              requested_document_type (str): The document type name that shall be created
              redirect_to (str): String that describes to where the method should redirect in case of an error

            Returns:
              HTTpResponse with a PDF when successful
              HTTpResponseRedirect when not successful

            Raises:
              raises Http404 exception if anything goes wrong"""
        from koalixcrm.crm.documents.contract import Contract
        try:
            new_document = requested_document_type()
            new_document.create_from_reference(calling_model)
            calling_model_admin.message_user(request, _(str(new_document) +
                                                        " created"))
            response = HttpResponseRedirect('/admin/crm/'+
                                            new_document.__class__.__name__.lower()+
                                            '/'+
                                            str(new_document.id))
        except (TemplateSetMissingInContract, TemplateMissingInTemplateSet) as e:
            if isinstance(calling_model, Contract):
                contract = calling_model
            else:
                contract = calling_model.contract
            if isinstance(e, TemplateSetMissingInContract):
                response = HttpResponseRedirect('/admin/crm/contract/'+
                                                str(contract.id))
                calling_model_admin.message_user(request, _("Missing Templateset "),
                                                 level=messages.ERROR)
            elif isinstance(e, TemplateMissingInTemplateSet):
                response = HttpResponseRedirect('/admin/djangoUserExtension/templateset/' +
                                                str(contract.default_template_set.id))
                calling_model_admin.message_user(request,
                                                 (_("Missing template for ")+
                                                  new_document.__class__.__name__),
                                                 level=messages.ERROR)
            else:
                raise Http404
        return response



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-01-04 21:38
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0009_auto_20180104_2111'),
    ]

    operations = [
        migrations.RenameField(
            model_name='position',
            old_name='positionPricePerUnit',
            new_name='position_price_per_unit',
        ),
    ]



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _

from filebrowser.fields import FileBrowseField

from koalixcrm.djangoUserExtension.user_extension.text_paragraph import InlineTextParagraph
from koalixcrm.global_support_functions import xstr
from koalixcrm.crm.exceptions import *


class DocumentTemplate(models.Model):
    title = models.CharField(verbose_name=_("Title"),
                             max_length=100,
                             blank=True,
                             null=True)
    xsl_file = FileBrowseField(verbose_name=_("XSL File"),
                               max_length=200)
    fop_config_file = FileBrowseField(verbose_name=_("FOP Configuration File"),
                                      blank=True,
                                      null=True,
                                      max_length=200)
    logo = FileBrowseField(verbose_name=_("Logo for the PDF generation"),
                           blank=True,
                           null=True,
                           max_length=200)

    def get_fop_config_file(self):
        if self.fop_config_file:
            return self.fop_config_file
        else:
            raise TemplateFOPConfigFileMissing(_("Fop Config File missing in Document Template"+str(self)))

    def get_xsl_file(self):
        if self.xsl_file:
            return self.xsl_file
        else:
            raise TemplateXSLTFileMissing(_("XSL Template missing in Document Template"+str(self)))

    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Document template')
        verbose_name_plural = _('Document templates')

    def __str__(self):
        return xstr(self.id) + ' ' + xstr(self.title.__str__())


class InvoiceTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Invoice template')
        verbose_name_plural = _('Invoice templates')


class QuoteTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Quote template')
        verbose_name_plural = _('Quote templates')


class DeliveryNoteTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Delivery note template')
        verbose_name_plural = _('Delivery note templates')


class PaymentReminderTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Payment reminder template')
        verbose_name_plural = _('Payment reminder templates')


class PurchaseOrderTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Purchase order template')
        verbose_name_plural = _('Purchase order templates')


class PurchaseConfirmationTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Purchase confirmation template')
        verbose_name_plural = _('Purchase confirmation templates')


class ProfitLossStatementTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Profit loss statement template')
        verbose_name_plural = _('Profit loss statement templates')


class BalanceSheetTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Balance sheet template')
        verbose_name_plural = _('Balance sheet templates')


class MonthlyProjectSummaryTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Monthly project summary template')
        verbose_name_plural = _('Monthly project summary templates')


class WorkReportTemplate(DocumentTemplate):
    class Meta:
        app_label = "djangoUserExtension"
        verbose_name = _('Work report template')
        verbose_name_plural = _('Work report templates')


class OptionDocumentTemplate(admin.ModelAdmin):
    list_display = ('id', 'title')
    list_display_links = ('id', 'title')
    ordering = ('id',)
    search_fields = ('id', 'title')
    fieldsets = (
        (_('Basics'), {
            'fields': ('title',
                       'xsl_file',
                       'fop_config_file',
                       'logo')
        }),
    )
    inlines = [InlineTextParagraph]




# -*- coding: utf-8 -*-

import factory
from koalixcrm.crm.models import ResourceType


class StandardResourceTypeFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = ResourceType

    title = 'This is a test Resource Type'
    description = "This is a description of such a Resource Type"



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _


class Unit(models.Model):
    description = models.CharField(verbose_name=_("Description"),
                                   max_length=100)
    short_name = models.CharField(verbose_name=_("Displayed Name After Quantity In The Position"),
                                  max_length=3)
    is_a_fraction_of = models.ForeignKey('self',
                                         on_delete=models.CASCADE,
                                         blank=True,
                                         null=True,
                                         verbose_name=_("Is A Fraction Of"))
    fraction_factor_to_next_higher_unit = models.DecimalField(verbose_name=_("Factor Between This And Next Higher Unit"),
                                                              max_digits=20,
                                                              decimal_places=10,
                                                              blank=True,
                                                              null=True)

    def __str__(self):
        return self.short_name

    class Meta:
        app_label = "crm"
        verbose_name = _('Unit')
        verbose_name_plural = _('Units')


class OptionUnit(admin.ModelAdmin):
    list_display = ('id',
                    'description',
                    'short_name',
                    'is_a_fraction_of',
                    'fraction_factor_to_next_higher_unit')
    fieldsets = (('', {'fields': ('description',
                                  'short_name',
                                  'is_a_fraction_of',
                                  'fraction_factor_to_next_higher_unit')}),)
    allow_add = True




# Generated by Django 2.1.5 on 2019-04-01 20:09

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0057_merge_20190106_1510'),
    ]

    operations = [
        migrations.RenameField(
            model_name='supplier',
            old_name='offersShipmentToCustomers',
            new_name='offers_shipment_to_customers',
        ),
    ]



# -*- coding: utf-8 -*-

import factory
from koalixcrm.crm.models import AgreementStatus


class AgreedAgreementStatusFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = AgreementStatus
        django_get_or_create = ('title',)

    title = "Done"
    description = "This agreement is agreed"
    is_agreed = True


class PlannedAgreementStatusFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = AgreementStatus
        django_get_or_create = ('title',)

    title = "Planned"
    description = "This agreement is planned"
    is_agreed = False


class StartedAgreementStatusFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = AgreementStatus
        django_get_or_create = ('title',)

    title = "Started"
    description = "This agreement is started"
    is_agreed = False



# -*- coding: utf-8 -*-

import factory
from koalixcrm.crm.models import UnitTransform
from koalixcrm.crm.factories.factory_unit import StandardUnitFactory, SmallUnitFactory
from koalixcrm.crm.factories.factory_product_type import StandardProductTypeFactory


class StandardUnitTransformFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = UnitTransform
        django_get_or_create = ('from_unit',
                                'to_unit')

    from_unit = factory.SubFactory(StandardUnitFactory)
    to_unit = factory.SubFactory(SmallUnitFactory)
    product_type = factory.SubFactory(StandardProductTypeFactory)
    factor = 1.10



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _
from koalixcrm.crm.product.price import Price
from koalixcrm.crm.reporting.resource import Resource


class ResourcePrice(Price):
    resource = models.ForeignKey(Resource,
                                 on_delete=models.CASCADE,
                                 verbose_name=_('Resource'),
                                 blank=False,
                                 null=False)

    def __str__(self):
        return str(self.price) + " " + str(self.currency.short_name)


class ResourcePriceInlineAdminView(admin.TabularInline):
    model = ResourcePrice
    extra = 1
    classes = ['collapse']
    fieldsets = (
        ('Basic', {
            'fields': ('price',
                       'currency',
                       'unit',
                       'valid_from',
                       'valid_until',
                       'customer_group')
        }),
    )
    allow_add = True



# -*- coding: utf-8 -*-

from django.contrib.admin.widgets import *


class RangeSelectionForm(forms.Form):
    """
    Form which allows to select the Range in which the work item can be registered
    and which define which range of work items are loaded from the database and shown
    to the user
    """
    from_date = forms.DateField(widget=AdminDateWidget)
    to_date = forms.DateField(widget=AdminDateWidget)
    original_from_date = forms.DateField(widget=forms.HiddenInput(),
                                         required=False)
    original_to_date = forms.DateField(widget=forms.HiddenInput(),
                                       required=False)

    def evaluate_pre_check_from_date(self):
        original_from_date = self.cleaned_data['original_from_date']
        new_from_date = self.cleaned_data['from_date']
        if original_from_date < new_from_date:
            from_date = original_from_date
        else:
            from_date = new_from_date
        return from_date

    def evaluate_pre_check_to_date(self):
        original_to_date = self.cleaned_data['original_to_date']
        new_to_date = self.cleaned_data['to_date']

        if original_to_date > new_to_date:
            to_date = original_to_date
        else:
            to_date = new_to_date
        return to_date

    def update_from_input(self):
        self.from_date = self.cleaned_data['from_date']
        self.to_date = self.cleaned_data['to_date']
        self.original_from_date = self.from_date
        self.original_to_date = self.to_date

    @staticmethod
    def create_range_selection_form(from_date, to_date):
        initial_form_data = {'from_date': from_date,
                             'to_date': to_date,
                             'original_from_date': from_date,
                             'original_to_date': to_date}
        range_selection_form = RangeSelectionForm(initial=initial_form_data)
        return range_selection_form




from rest_framework import serializers

from koalixcrm.crm.reporting.resource import Resource
from koalixcrm.crm.reporting.resource_type import ResourceType
from koalixcrm.crm.reporting.resource_manager import ResourceManager
from koalixcrm.crm.rest.resource_manager_rest import OptionResourceManagerJSONSerializer
from koalixcrm.crm.rest.resource_type_rest import OptionResourceTypeJSONSerializer


class OptionResourceJSONSerializer(serializers.HyperlinkedModelSerializer):
    resourceType = OptionResourceTypeJSONSerializer(required=False, read_only=True)
    resourceManager = OptionResourceManagerJSONSerializer(read_only=True)

    class Meta:
        model = Resource
        fields = ('resource_type',
                  'resource_manager')


class ResourceJSONSerializer(serializers.HyperlinkedModelSerializer):
    resourceType = OptionResourceTypeJSONSerializer()
    resourceManager = OptionResourceManagerJSONSerializer()

    class Meta:
        model = Resource
        fields = ('resource_type',
                  'resource_manager')

    def create(self, validated_data):
        resource = Resource()
        # Deserialize resource_type
        resource_type = validated_data.pop('resource_type')
        if resource_type:
            if resource_type.get('id', None):
                resource.resource_type = ResourceType.objects.get(id=resource_type.get('id', None))
            else:
                resource.resource_type = None
        # Deserialize resource_manager
        resource_manager = validated_data.pop('resourceManager')
        if resource_manager:
            if resource_manager.get('id', None):
                resource.resource_manager = ResourceManager.objects.get(id=resource_manager.get('id', None))
            else:
                resource.resource_manager = None

    def update(self, resource, validated_data):
        # Deserialize resource_type
        resource_type = validated_data.pop('resource_type')
        if resource_type:
            if resource_type.get('id', resource.resource_type):
                resource.resource_type = ResourceType.objects.get(id=resource_type.get('id', None))
            else:
                resource.resource_type = resource.resource_type_id
        else:
            resource.resource_type = None
        # Deserialize resource_manager
        resource_manager = validated_data.pop('resourceManager')
        if resource_manager:
            if resource_manager.get('id', resource.resource_manager):
                resource.resource_manager = ResourceManager.objects.get(id=resource.get('id', None))
            else:
                resource.resource_manager = resource.resource_manager_id
        else:
            resource.resource_manager = None



# -*- coding: utf-8 -*-

import factory
import datetime
from koalixcrm.crm.models import Task
from koalixcrm.crm.factories.factory_project import StandardProjectFactory
from koalixcrm.crm.factories.factory_task_status import StartedTaskStatusFactory
from koalixcrm.global_support_functions import make_date_utc


class StandardTaskFactory(factory.django.DjangoModelFactory):
    class Meta:
        model = Task

    title = 'This is a test Task'
    project = factory.SubFactory(StandardProjectFactory)
    description = "This is a description"
    status = factory.SubFactory(StartedTaskStatusFactory)
    last_status_change = make_date_utc(datetime.datetime(2018, 6, 15, 00))



from rest_framework import serializers

from koalixcrm.djangoUserExtension.user_extension.user_extension import UserExtension
from koalixcrm.crm.reporting.human_resource import HumanResource
from koalixcrm.crm.reporting.resource_type import ResourceType
from koalixcrm.crm.reporting.resource_manager import ResourceManager
from koalixcrm.djangoUserExtension.rest.user_extension_rest import OptionUserExtensionJSONSerializer
from koalixcrm.crm.rest.resource_manager_rest import OptionResourceManagerJSONSerializer
from koalixcrm.crm.rest.resource_type_rest import OptionResourceTypeJSONSerializer


class OptionHumanResourceJSONSerializer(serializers.HyperlinkedModelSerializer):
    resourceType = OptionResourceTypeJSONSerializer(source='resource_type',
                                                    required=False,
                                                    read_only=True)
    resourceManager = OptionResourceManagerJSONSerializer(source='resource_manager',
                                                          read_only=True)
    user = OptionResourceManagerJSONSerializer(source='user',
                                               read_only=True)

    class Meta:
        model = HumanResource
        fields = ('user',
                  'resource_manager',
                  'resource_type')


class HumanResourceJSONSerializer(serializers.HyperlinkedModelSerializer):
    resourceType = OptionResourceTypeJSONSerializer(source='resource_type')
    resourceManager = OptionResourceManagerJSONSerializer(source='resource_manager')
    user = OptionResourceManagerJSONSerializer(source='user')

    class Meta:
        model = HumanResource
        fields = ('user',
                  'resource_type',
                  'resource_manager')

    def create(self, validated_data):
        resource = HumanResource()
        # Deserialize resource_type
        resource_type = validated_data.pop('resourceType')
        if resource_type:
            if resource_type.get('id', None):
                resource.resource_type = ResourceType.objects.get(id=resource_type.get('id', None))
            else:
                resource.resource_type = None
        # Deserialize resource_manager
        resource_manager = validated_data.pop('resourceManager')
        if resource_manager:
            if resource_manager.get('id', None):
                resource.resource_manager = ResourceManager.objects.get(id=resource_manager.get('id', None))
            else:
                resource.resource_manager = None
        # Deserialize resource_manager
        user = validated_data.pop('user')
        if user:
            if user.get('id', None):
                resource.user = UserExtension.objects.get(id=user.get('id', None))
            else:
                resource.user = None

    def update(self, resource, validated_data):
        # Deserialize resource_type
        resource_type = validated_data.pop('resourceType')
        if resource_type:
            if resource_type.get('id', resource.resource_type):
                resource.resource_type = ResourceType.objects.get(id=resource_type.get('id', None))
            else:
                resource.resource_type = resource.resource_type_id
        else:
            resource.resource_type = None
        # Deserialize resource_manager
        resource_manager = validated_data.pop('resourceManager')
        if resource_manager:
            if resource_manager.get('id', resource.resource_manager):
                resource.resource_manager = ResourceManager.objects.get(id=resource.get('id', None))
            else:
                resource.resource_manager = resource.resource_manager_id
        else:
            resource.resource_manager = None
        # Deserialize user
        user = validated_data.pop('user')
        if user:
            if user.get('id', resource.resource_manager):
                resource.user = UserExtension.objects.get(id=user.get('id', None))
            else:
                resource.user = resource.user_id
        else:
            resource.user = None



# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2018-10-12 20:56
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('crm', '0053_auto_20181014_2305'),
        ('accounting', '0008_auto_20181012_2056'),
    ]

    operations = [
        migrations.DeleteModel(
            name='ProductCategorie',
        ),
        migrations.AddField(
            model_name='productcategory',
            name='loss_account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_loss_account', to='accounting.Account', verbose_name='Loss Account'),
        ),
        migrations.AddField(
            model_name='productcategory',
            name='profit_account',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='db_profit_account', to='accounting.Account', verbose_name='Profit Account'),
        ),
    ]



# -*- coding: utf-8 -*-

from django.db import models
from django.contrib import admin
from django.utils.translation import ugettext as _


class CustomerBillingCycle(models.Model):
    name = models.CharField(max_length=300,
                            verbose_name=_("Name"))
    time_to_payment_date = models.IntegerField(verbose_name=_("Days To Payment Date"))
    payment_reminder_time_to_payment = models.IntegerField(verbose_name=_("Payment Reminder, Days To Payment Date "))

    class Meta:
        app_label = "crm"
        verbose_name = _('Customer Billing Cycle')
        verbose_name_plural = _('Customer Billing Cycle')

    def __str__(self):
        return self.id.__str__() + ' ' + self.name


class OptionCustomerBillingCycle(admin.ModelAdmin):
    list_display = ('id',
                    'name',
                    'time_to_payment_date',
                    'payment_reminder_time_to_payment')
    fieldsets = (('', {'fields': ('name',
                                  'time_to_payment_date',
                                  'payment_reminder_time_to_payment',
                                  )}),)
    allow_add = True
